darkhistory.electrons.ics.nonrel\_diff\_terms.H\_and\_G
=======================================================

.. currentmodule:: darkhistory.electrons.ics.nonrel_diff_terms

.. autofunction:: H_and_G